import ActionAlert from "./ActionAlert";
import ActionModal from "./ActionModal";
import ActionCallback from "./ActionCallback";
import ActionConsole from "./ActionConsole";
/**
 * Actions.
 *
 * @since 1.0.0
 */
export default class Actions {
    actions = [];
    /**
     * Constructor.
     *
     * @param form Form instance.
     * @param actionsData Actions data.
     *
     * @since 1.0.0
     */
    constructor(actionsData) {
        actionsData.forEach(actionData => {
            let action;
            switch (actionData.type) {
                case "alert":
                    action = new ActionAlert(actionData.data);
                    this.actions.push(action);
                    break;
                case "modal":
                    action = new ActionModal(actionData.data);
                    this.actions.push(action);
                    break;
                case "console":
                    action = new ActionConsole(actionData.data);
                    this.actions.push(action);
                    break;
                case "callback":
                    action = new ActionCallback(actionData.data);
                    this.actions.push(action);
                    break;
                default:
                    throw new Error("Action type '" + actionData.type + "' does not exist.");
            }
        });
    }
    /**
     * Run all actions.
     *
     * @since 1.0.0
     */
    run() {
        let run = true;
        this.actions.forEach(action => {
            if (run) {
                run = action.run();
            }
        });
    }
}
